@@ -22,6 +22,7 @@ pub fn draw(
     colors: AppColors,
     error: &AppError,
     f: &mut Frame,
+    host: Option<String>,
     keymap: &Keymap,
     seconds: Option<u8>,
 ) {
@@ -31,13 +32,21 @@ pub fn draw(
         .title_alignment(Alignment::Center)
         .borders(Borders::ALL);
 
-    let to_push = if matches!(error, AppError::DockerConnect) {
-        format!(
-            "\n\n {}::v{} closing in {:02} seconds",
+    let mut text = format!("\n{error}");
+
+    if error == &AppError::DockerConnect {
+        let s = if let Some(host) = host {
+            format!(" @ \"{host}\"")
+        } else {
+            String::new()
+        };
+        text.push_str(&format!(
+            "{}\n\n {}::v{} closing in {:02} seconds",
+            s,
             NAME,
             VERSION,
-            seconds.unwrap_or(5)
-        )
+            seconds.unwrap_or(5),
+        ))
     } else {
         let clear_text = if keymap.clear == Keymap::new().clear {
             format!("( {} ) {SUFFIX_CLEAR}", keymap.clear.0)
@@ -46,20 +55,17 @@ pub fn draw(
         } else {
             format!(" ( {} ) {SUFFIX_CLEAR}", keymap.clear.0)
         };
+        text.push_str(&format!("\n\n{clear_text}"));
+    }
 
-        let quit_text = if keymap.quit == Keymap::new().quit {
-            format!("( {} ) {SUFFIX_QUIT}", keymap.quit.0)
-        } else if let Some(secondary) = keymap.quit.1 {
-            format!(" ( {} | {secondary} ) {SUFFIX_QUIT}", keymap.quit.0)
-        } else {
-            format!(" ( {} ) {SUFFIX_QUIT}", keymap.quit.0)
-        };
-        format!("\n\n{clear_text}\n\n{quit_text}")
+    let quit_text = if keymap.quit == Keymap::new().quit {
+        format!("( {} ) {SUFFIX_QUIT}", keymap.quit.0)
+    } else if let Some(secondary) = keymap.quit.1 {
+        format!(" ( {} | {secondary} ) {SUFFIX_QUIT}", keymap.quit.0)
+    } else {
+        format!(" ( {} ) {SUFFIX_QUIT}", keymap.quit.0)
     };
-
-    let mut text = format!("\n{error}");
-
-    text.push_str(to_push.as_str());
+    text.push_str(&format!("\n\n{quit_text}"));
 
     // Find the maximum line width & height
     let padded_width = max_line_width(&text) + 8;
@@ -106,8 +112,7 @@ mod tests {
     #[test]
     /// Test that the error popup is centered, red background, white border, white text, and displays the correct text
     fn test_draw_blocks_error_docker_connect_error() {
-        let mut setup = test_setup(46, 9, true, true);
-
+        let mut setup = test_setup(50, 11, true, true);
         setup
             .terminal
             .draw(|f| {
@@ -115,6 +120,7 @@ mod tests {
                     AppColors::new(),
                     &AppError::DockerConnect,
                     f,
+                    None,
                     &Keymap::new(),
                     Some(4),
                 );
@@ -123,12 +129,50 @@ mod tests {
         assert_snapshot!(setup.terminal.backend());
         for (row_index, result_row) in get_result(&setup) {
             for (result_cell_index, result_cell) in result_row.iter().enumerate() {
-                if let (0 | 8, _) = (row_index, result_cell_index) {
-                    assert_eq!(result_cell.bg, Color::Reset);
-                    assert_eq!(result_cell.fg, Color::Reset);
-                } else {
-                    assert_eq!(result_cell.bg, Color::Red);
-                    assert_eq!(result_cell.fg, Color::White);
+                match (row_index, result_cell_index) {
+                    (0 | 10, _) | (_, 0 | 49) => {
+                        assert_eq!(result_cell.bg, Color::Reset);
+                        assert_eq!(result_cell.fg, Color::Reset);
+                    }
+                    _ => {
+                        assert_eq!(result_cell.bg, Color::Red);
+                        assert_eq!(result_cell.fg, Color::White);
+                    }
+                }
+            }
+        }
+    }
+
+    #[test]
+    /// Test that the error popup is centered, red background, white border, white text, and displays the correct text with the custom docker host address
+    fn test_draw_blocks_error_docker_connect_error_custom_host() {
+        let mut setup = test_setup(60, 11, true, true);
+
+        setup
+            .terminal
+            .draw(|f| {
+                super::draw(
+                    AppColors::new(),
+                    &AppError::DockerConnect,
+                    f,
+                    Some("/test/host.sock".to_owned()),
+                    &Keymap::new(),
+                    Some(4),
+                );
+            })
+            .unwrap();
+        assert_snapshot!(setup.terminal.backend());
+        for (row_index, result_row) in get_result(&setup) {
+            for (result_cell_index, result_cell) in result_row.iter().enumerate() {
+                match (row_index, result_cell_index) {
+                    (0 | 10, _) | (_, 0 | 59) => {
+                        assert_eq!(result_cell.bg, Color::Reset);
+                        assert_eq!(result_cell.fg, Color::Reset);
+                    }
+                    _ => {
+                        assert_eq!(result_cell.bg, Color::Red);
+                        assert_eq!(result_cell.fg, Color::White);
+                    }
                 }
             }
         }
@@ -146,6 +190,7 @@ mod tests {
                     AppColors::new(),
                     &AppError::DockerExec,
                     f,
+                    None,
                     &Keymap::new(),
                     Some(4),
                 );
@@ -183,7 +228,14 @@ mod tests {
         setup
             .terminal
             .draw(|f| {
-                super::draw(colors, &AppError::DockerExec, f, &Keymap::new(), Some(4));
+                super::draw(
+                    colors,
+                    &AppError::DockerExec,
+                    f,
+                    None,
+                    &Keymap::new(),
+                    Some(4),
+                );
             })
             .unwrap();
 
@@ -218,7 +270,14 @@ mod tests {
         setup
             .terminal
             .draw(|f| {
-                super::draw(AppColors::new(), &AppError::DockerExec, f, &keymap, None);
+                super::draw(
+                    AppColors::new(),
+                    &AppError::DockerExec,
+                    f,
+                    None,
+                    &keymap,
+                    None,
+                );
             })
             .unwrap();
         assert_snapshot!(setup.terminal.backend());
@@ -235,7 +294,14 @@ mod tests {
         setup
             .terminal
             .draw(|f| {
-                super::draw(AppColors::new(), &AppError::DockerExec, f, &keymap, None);
+                super::draw(
+                    AppColors::new(),
+                    &AppError::DockerExec,
+                    f,
+                    None,
+                    &keymap,
+                    None,
+                );
             })
             .unwrap();
         assert_snapshot!(setup.terminal.backend());
@@ -252,7 +318,14 @@ mod tests {
         setup
             .terminal
             .draw(|f| {
-                super::draw(AppColors::new(), &AppError::DockerExec, f, &keymap, None);
+                super::draw(
+                    AppColors::new(),
+                    &AppError::DockerExec,
+                    f,
+                    None,
+                    &keymap,
+                    None,
+                );
             })
             .unwrap();
         assert_snapshot!(setup.terminal.backend());
